@@ -1,8 +1,8 @@
 # File::Repl
 #
 # Version
-#      $Source: D:/src/perl/File/Repl/RCS/Repl.pm $
-#      $Revision: 1.19 $
+#      $Source: D:/src/perl/File/Repl/RCS/repl.pm $
+#      $Revision: 1.29 $
 #      $State: Exp $
 #
 # Start comments/code here - will not be processed into manual pages
@@ -10,7 +10,38 @@
 #    Copyright  Dave Roberts  2000,2001
 #
 # Revision history:
-#      $Log: Repl.pm $
+#      $Log: repl.pm $
+#      Revision 1.29  2010/05/04 15:02:05  Dave.Roberts
+#      corrected documentation - layout near Update method was incorrect
+#
+#      Revision 1.28  2010/04/27 14:55:00  Dave.Roberts
+#      minor code improvements in output messages for the Delete method
+#
+#      Revision 1.27  2010/04/13 08:36:52  Dave.Roberts
+#      added functionality for testing negative ages. This allows files older than the age
+#      specified to be selected (excluding all files younger)
+#
+#      Revision 1.26  2010/04/12 16:29:57  Dave.Roberts
+#      added Version method to return the File::Repl version
+#      corrected silly mistake in documentation - in definition of %con hash
+#
+#      Revision 1.25  2010/04/12 16:04:54  Dave.Roberts
+#      added example script for tombstoning
+#      removed windows linefeed characters from file
+#
+#      Revision 1.24  2010/04/07 02:00:11  Dave.Roberts
+#      modified code to remove the use of a hash as a reference - this was generating warnings
+#      as this use of a hash has beeen depreciated.
+#
+#      Revision 1.21  2002/02/07 10:37:39  Dave.Roberts
+#      corrected mode identified for Update method (the check used previously
+#      was invalid), and also synopsis for use of Update method (args incorrectly
+#      ordered)
+#
+#      Revision 1.20  2002/01/09 12:51:17  Dave.Roberts
+#      corrected errors in tombstoning of directories - subs $del and
+#      $deltree in particular
+#
 #      Revision 1.19  2001/11/21 21:28:19  Dave.Roberts
 #      resolved error in determining file age, especially when the 'a' file is
 #      missing
@@ -106,7 +137,7 @@ if ($^O eq 'MSWin32') {        # is this a win32 system ?
     if ( $id == 2 ) {   #  Machine is NT (0=Win32s, 1=Win9x etc)
       eval "use Win32::API";
       eval "use Win32::AdminMisc";
-  
+
       my $lpTimeZoneInformation = "\0" x 172;   # space for struct _TIME_ZONE_INFORMATION
       my $GetTimeZoneInformation = new Win32::API("kernel32", 'GetTimeZoneInformation', ['P'], 'N');
       croak "\n ERROR: failed to import GetTimeZoneInformation API function\n" if !$GetTimeZoneInformation;
@@ -114,11 +145,11 @@ if ($^O eq 'MSWin32') {        # is this a win32 system ?
       croak "\n ERROR: GetTimeZoneInformation returned invalid data: " . Win32::FormatMessage(Win32::GetLastError())
       if $ISDST == TIME_ZONE_ID_INVALID;
       my ($Bias,$StandardBias,$DaylightBias) = unpack "l x80 l x80 l", $lpTimeZoneInformation;
-  
+
 # $ISDST == 0 -  No Daylight Savings in this timezone (no transition dates defined for this tz)
 # $ISDST == 1 -  Standard time
 # $ISDST == 2 -  Daylight Savings time
-  
+
 # bias times are returned in minutes - convert to seconds
       $TZ_BIAS = ($Bias + ($ISDST == 0 ? 0 : ($ISDST == 2 ? $DaylightBias : $StandardBias))) * 60;
     }
@@ -133,16 +164,16 @@ our @ISA = qw(Exporter);
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-# This allows declaration	use File::Repl ':all';
+# This allows declaration		 use File::Repl ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
-	
+
 );
 
-our $VERSION = sprintf("%d.%d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = sprintf("%d.%d", q$Revision: 1.29 $ =~ /(\d+)\.(\d+)/);
 
 # Preloaded methods go here.
 #---------------------------------------------------------------------
@@ -153,7 +184,7 @@ sub New {
   my($alist,$blist,$atype,$btype,$key,$xxx,$dira,$dirb,$tmp);
   $conf->{dira} =~ s/\\/\//g;     # Make dir use forward slash's
   $conf->{dirb} =~ s/\\/\//g;     # Make dir use forward slash's
-  
+
 # To maintain backwards compatibility, check if additional
 # keys are defined and default to a suitable value (NH271100)
   my $r_con = {
@@ -176,7 +207,7 @@ sub New {
       printf "  Key %-10s   Value %-30s\n",$key, $r_con->{$key};
     }
   }
-  
+
 # Build the A list
   benchmark("init") if $r_con->{bmark};
   if ( -d $r_con->{dira} ) {
@@ -199,7 +230,7 @@ sub New {
     croak "Invalid directory name for dira ($r_con->{dira})\n";
   }
   benchmark("build A list") if $r_con->{bmark};
-  
+
 # Build the B list
   benchmark("init") if $r_con->{bmark};
   if ( $r_con->{dira} eq $r_con->{dirb} ) {
@@ -241,6 +272,10 @@ sub Rename {
   return _generic ("Rename",@_);
 }
 #=====================================================================
+sub Version {
+  return $VERSION;
+}
+#=====================================================================
 sub Process {
   if ( scalar(@_) eq 3 ) {
     my($r_con,$regex,$sub) =@_;
@@ -283,7 +318,7 @@ sub _generic {
   my $tz_bias_a = 0;
   my $tz_bias_b = 0;
   my $fudge = 2;  # Fudge factor to allow two machines to synch via a removeable drive/disc (A <> DOS <> B)
-  
+
   if ($caller eq "Update") {
     if ( scalar(@_) == 4 ) {
       ($r_con,$regex,$mode,$commit) = @_;
@@ -298,7 +333,7 @@ sub _generic {
       $mode      = 'a>b';
       print "using default mode for Update method (a>b)\n" if ($verbose > 1);
     }
-    if ( ! $mode =~ /^(A>B!?)|(A<>B)|(A<B!?)|(a[<>]b)|(a<>b)$/ ) {
+    if ( $mode !~ /^(A>B!?)|(A<>B)|(A<B!?)|(a[<>]b)|(a<>b)$/ ) {
       carp("Illegal mode used for Update method - legal options are\n\tA>B\tA>B!\tA<B\tA<B!\n\tA<>B\ta<b\ta>b\ta<>b\n");
       return;
     }
@@ -330,19 +365,20 @@ sub _generic {
   if ($TZ_BIAS) {
     if ( ( $r_con->{dira} =~ /^([a-z]:)/i ) ||                   # First match a drive letter - ie D:
     ( $r_con->{dira} =~ /^([\\\/].\w+[\\\/][a-z0-9\$]+)/i ) ||   # Else match a share - ie //comp/share or \\comp\share
-    ( Win32::GetCwd() =~ /^([a-z]:)/i ) ) {                      # Else assume relative path - use CWD 
+    ( Win32::GetCwd() =~ /^([a-z]:)/i ) ) {                      # Else assume relative path - use CWD
       %vol = Win32::AdminMisc::GetVolumeInfo( $1 );
       $tz_bias_a = $TZ_BIAS if ($vol{FileSystemName} =~ m/FAT/);
     }
     if ( ( $r_con->{dirb} =~ /^([a-z]:)/i ) ||                   # First match a drive letter - ie D:
     ( $r_con->{dirb} =~ /^([\\\/].\w+[\\\/][a-z0-9\$]+)/i ) ||   # Else match a share - ie //comp/share or \\comp\share
-    ( Win32::GetCwd() =~ /^([a-z]:)/i ) ) {                      # Else assume relative path - use CWD 
+    ( Win32::GetCwd() =~ /^([a-z]:)/i ) ) {                      # Else assume relative path - use CWD
        %vol = Win32::AdminMisc::GetVolumeInfo( $1 );
       $tz_bias_b = $TZ_BIAS if ($vol{FileSystemName} =~ m/FAT/);
     }
     $tz_bias_a = $tz_bias_b = 0 if ($tz_bias_a && $tz_bias_b);
   }
-
+  
+if ($caller eq "Update") { 
   print "Update
   Regex    : $regex
   NegRegex : $negregex
@@ -352,7 +388,15 @@ sub _generic {
   Tombstone File TTL : $ttl
   DirA DOS time adj  : $tz_bias_a
   DirB DOS time adj  : $tz_bias_b\n\n" if ($verbose >= 3);
-  
+}elsif ($caller eq "Delete"){
+  print "Delete
+  Regex    : $regex
+  NegRegex : $negregex
+  Commit   : $commit
+  AgeLimit : $r_con->{agelimit} days ($agelimit seconds)
+  Tombstone File TTL : $ttl
+  DirA DOS time adj  : $tz_bias_a\n\n" if ($verbose >= 3);
+}
 # Sort files using regex and negregex
   benchmark("init") if $r_con->{bmark};
   ($tfiles,$common,$aonly,$bonly,$amatch,$bmatch) =
@@ -391,10 +435,20 @@ sub _generic {
     }else{
       ($bmtime > $amtime) ? $age = $bmtime : $age = $amtime; # Find the most recent mtime ($age)
     }
-    if ( $agelimit && (( $runtime - $age ) > $agelimit )) { # Test for agelimit exceeded
-      #print "amtime $amtime\nbmtime $bmtime\nage    $age\n";
-      printf "%s - exceeds age limit (%3.1d days old - limit is set to %3d days)\n",$msg,(time - $age)/86400,$agelimit/86400 if ($verbose > 1);
-      return FALSE;
+	if ( $agelimit ){
+	   if ($agelimit > 0) {   # if $agelimit is positive - ignore files older than the agelimit
+          if ( ( $runtime - $age ) > $agelimit ) { # Test for agelimit exceeded
+            #print "amtime $amtime\nbmtime $bmtime\nage    $age\n";
+            printf "%s - exceeds age limit (%3.1d days old - limit is set to less than %3d days)\n",$msg,(time - $age)/86400,$agelimit/86400 if ($verbose > 1);
+            return FALSE;
+          }
+	   }else{                 # agelimit is negative - ignore files newer than the agelimit
+          if ( ( $runtime - $age ) > -$agelimit ) { # Test for agelimit exceeded
+            #print "amtime $amtime\nbmtime $bmtime\nage    $age\n";
+            printf "%s - is less than the minimum age limit (%3.1d days old - limit is set to greater than %3d days)\n",$msg,(time - $age)/86400,-$agelimit/86400 if ($verbose > 1);
+            return FALSE;
+          }
+	   }
     }
     if ( ! $commit ) {
       print "$msg\n"  if ($verbose >= 1);
@@ -413,7 +467,7 @@ sub _generic {
           undef $Btmp;
         }
       }
-      
+
       if ( copy ($A,$B) ) {
         print "$msg\n"  if ($verbose >= 1);
 # ******
@@ -444,7 +498,7 @@ sub _generic {
     }
     return FALSE;
   };
-  
+
 #****************************************************************
 # sub to test a directory tree exists, and if not to create it
 #****************************************************************
@@ -459,22 +513,36 @@ sub _generic {
     }
     return(-d $Dir);
   };
-  
+
 #****************************************************************
 # sub to delete directories / files
 #****************************************************************
-  $del = sub {
+ $del = sub {
     my($targ, $mtime) = @_;
-    print "del ($targ,$mtime)\n" if $verbose > 3;
+    #print "del ($targ,$mtime)\n" if $verbose > 3;
     my($msg);
-    (-d $targ) ? $msg = "  rmdir  $targ" : $msg = "  rm $targ";
-    if ( $mtime && $agelimit && (( $runtime - $mtime ) > $agelimit )) {
-      printf "%s - exceeds age limit (%3.1d days - limit is %3d days))\n", $msg, (time - $mtime)/(86400), $agelimit/(86400) if ( $verbose > 1 );
-      return FALSE;
+    if (-d $targ) {
+      $msg = "  rmdir  $targ";
+    }elsif (-f $targ) {
+      $msg = "  rm $targ";
+    }
+    if ( $mtime && $agelimit ) {
+	   if ( $agelimit > 0) {  # if $agelimit is positive - ignore files older than the agelimit 
+          if ( ( $runtime - $mtime ) > $agelimit ) {
+            printf "%s - exceeds age limit (%3.1d days - limit is newer than %3.1d days))\n", $msg, (time - $mtime)/(86400), $agelimit/(86400) if ( $verbose > 1 );
+            return FALSE;
+          }
+       }else{ #  if $agelimit is negative - ignore files newer than the agelimit
+          if ( ( $runtime - $mtime ) < -$agelimit ) {
+            printf "%s - under age limit (%3.1d days - limit is older than %3.1d days))\n", $msg, (time - $mtime)/(86400), -$agelimit/(86400) if ( $verbose > 1 );
+            return FALSE;
+          }
+       }
     }else{
-      print "$msg\n" if ($verbose >= 1);
+      print "$msg\n" if (($commit eq 0) & ($verbose >= 1));
     }
   return TRUE unless $commit;
+  print "$msg\n";
   if (-d $targ) {
     rmdir $targ || carp "Unable to delete directory $targ\n";
     return ! -d $targ;
@@ -493,14 +561,25 @@ sub _generic {
 $deltree = sub {
   my($targ,$dir,$reftime,$reftype,$top) = @_;
   my $xxx = sub {
-    ($tmp = $File::Find::name) =~ s/^\Q$dir//;      # Remove the start directory portion
-    return if (!$top && !rindex($tmp, '/'));        # Don't remove top level directory unless $top == TRUE
-    chdir $dir if !rindex($tmp, '/');               # Move up to parent if removing top level dir
-    delete $$reftime->{$tmp}, delete $$reftype->{$tmp} if &$del($File::Find::name);
+    ($tmp = $File::Find::name) =~ s/^\Q$dir//; # identify relative filename (to $dir)
+    return if ($tmp eq $targ);                 # Don't remove top level directory unless $top == TRUE
+    if (&$del($File::Find::name)) {
+      delete $reftime->{$tmp};
+      delete $reftype->{$tmp};
+    }
   };
   finddepth(\&$xxx, $dir . $targ);
-  return if $top;
-  $commit ? $$reftime->{$targ} = (stat($dir . $targ))[9] : $$reftime->{$targ} = $runtime;
+  if ($top) {
+    chdir $dir;
+		 if (rmdir "$dir$targ") {
+      delete $reftime->{$targ};
+      delete $reftype->{$targ};
+    }else{
+		   print "failed to rmdir $dir$targ\n";
+    }
+  }else{
+    $commit ? $$reftime->{$targ} = (stat($dir . $targ))[9] : $$reftime->{$targ} = $runtime;
+  }
 };
 
 #****************************************************************
@@ -527,6 +606,7 @@ $touch = sub {
   if ($commit) {
     open(FILE, ">> $file") || carp "Failed to touch $file\n";
     close(FILE);
+    chmod (0666,$file);
   }
   ($$type_ref, $$mtime_ref) = $commit ? (stat($file))[2,9] : $runtime;
 };
@@ -555,7 +635,7 @@ if ( $caller eq "Update" ) {
 #****************************************************************
   foreach $tName (@$tfiles) {
     ($name = $tName) =~ s/.remove$//i;
-    
+
 # Delete <dir.remove> trees and touch a file with same name
     if (-d $r_con->{dira} . $tName) {
       &$deltree($tName, $r_con->{dira}, $refa, $refatype, TRUE);
@@ -565,7 +645,7 @@ if ( $caller eq "Update" ) {
       &$deltree($tName, $r_con->{dirb}, $refb, $refbtype, TRUE);
       &$touch($r_con->{dirb} . $tName, \$refb->{$tName}, $refbtype->{$tName});
     }
-    
+
 # Delete <dir> trees and files
     if ($r_con->{nocase}) {
       ($aName) = grep { /^$name$/i } (keys %$refa);
@@ -658,10 +738,10 @@ if ( $caller eq "Update" ) {
     $btype  = $refbtype->{$bName};
     $afile  = $r_con->{dira} . $aName;
     $bfile  = $r_con->{dirb} . $bName;
-    
+
 # Skip directories as their time can't be set (NH251100)
     next if -d $afile;
-    
+
     if ( $amtime > ($bmtime + $fudge) ) {
       $amtime += $tz_bias_b;
       if ( $mode =~ /^(a>b)|(a<>b)|(A>B)|(A>B!)|(A<>B)$/ ) {
@@ -717,7 +797,7 @@ if ( $caller eq "Update" ) {
           delete $refa->{$f};
           delete $refatype->{$f};
         }
-      }        
+      }
     }else{
       carp "unable to understand substition  argument $nsub\n";
     }
@@ -756,7 +836,7 @@ sub _arraysort {
   foreach $name (keys %$refa) {
     if ( $name && ($name =~ /$regexextn$regex/) && ($name !~ /$regexextn$negregex/) ) {
       push (@amatch,$name);
-      printf"  %s  %s  %s\n",%$refa->{$name},%$refatype->{$name},$name if ($r_con->{verbose} >= 4);
+      #printf"  %s  %s  %s\n",%$refa->{$name},%$refatype->{$name},$name if ($r_con->{verbose} >= 4);
     }
   }
 # Find files matching the regex in dirb
@@ -764,7 +844,7 @@ sub _arraysort {
   foreach $name (keys %$refb) {
     if ( $name && $name =~ /$regexextn$regex/ && $name !~ /$regexextn$negregex/ ) {
       push (@bmatch,$name);
-      printf"  %s  %s  %s\n",%$refb->{$name},%$refbtype->{$name},$name if ($r_con->{verbose} >= 4);
+      #printf"  %s  %s  %s\n",%$refb->{$name},%$refbtype->{$name},$name if ($r_con->{verbose} >= 4);
     }
   }
 # Build a list of files that have an added extension ".remove" - to be deleted by tombstone routines later
@@ -826,7 +906,7 @@ sub _arraysort {
     foreach (@bonly) {
       print "  $_\n";
     }
-    print "Replicating ...\n";
+    print "\n\nEnd of File Lists ...\n\n";
   }
   return (\@tfiles, \%common, \@aonly, \@bonly, \@amatch, \@bmatch);
 }
@@ -856,16 +936,16 @@ File::Repl - Perl module that provides file replication utilities
 
   use File::Repl;
 
-  %con = {
+  %con = (
     dira     => 'C:/perl',
     dirb     => 'M:/perl',
     verbose  => '1',
     age      => '10',
-  };
+  );
 
   $ref=File::Repl->New(\%con);
   $r1 = $ref->Update('\.p(l|m)','a<>b',1);
-  $r2 = $ref->Update('\.t.*','a<>b',1,'\.tmp$');
+  $r2 = $ref->Update('\.t.*','\.tmp$','a<>b',1);
 
 =head1 DESCRIPTION
 
@@ -957,10 +1037,14 @@ method) are printed.
 This specifies the  maximum age of a file in days.  Files older than this will
 be ignored by Update, Rename, Compress and Delete methods.
 
+If the age is specified as a negative number files newer than this age will be ignored.
+
+A default value of zero causes no age limit to be tested - all files are accepted on age limits.
+
 =item recurse
 
 When set to FALSE only files at the top level of the B<dira> and B<dirb> are scanned. Default
-value is
+value is TRUE
 
 =item ttl
 
@@ -986,13 +1070,14 @@ hash (from the B<New> method) and four associated arguments.
 This method also allows
 files to be tombstoned (ie removed from the replicated file sets).  A file is tombstoned
 by appending I<.remove> to the file name.  The first B<Update> will cause the file to be
-set to zero size, and any replica files to be renamed (so the original file does not
+set to zero size, and any replica files to be renamed (so that the original file does not
 return).  The next update after the B<ttl> has expired will cause deletion of all file
 replicas.
 
 If a directory is tombstoned (by adding I<.remove> to its name) the directory and contents
 are removed and a file with the directory name and the I<.remove> suffix replaces it.  The
-file is removed as a normally tombstoned file.
+file is removed as a normally tombstoned file.  Note that tombstoning ignores the Update
+action qualifiers.
 
 The Update method returns a reference to data structures evaluated during the method call.
 This is based on the method arguments, and allows arrays and hash's of the file structure
@@ -1013,7 +1098,8 @@ An optional regular expression used to match all files not to be maintained
 
 =item B<action>
 
-defines the action to be performed.
+defines the action to be performed. Note that tombstoning activities ignore the action
+and assume the A<>B directive for those files and directories being tombstoned.
 
 =over 4
 
@@ -1151,6 +1237,10 @@ When set TRUE makes deletions required - set FALSE to show potential changes
 
 =back
 
+=item B<Version>
+
+The Version method returns the File::Repl module version. No calling argument is necessary.
+
 =head1 REQUIRED MODULES
 
   File::Find;
@@ -1207,7 +1297,7 @@ A simple example that retrieves and prints the working variables from the I<Upda
     &$sub($$my{$key});
   }
 
-and a sample output 
+and a sample output
 
   References and values of $my
   amatch:
@@ -1256,6 +1346,55 @@ I<nocase> value the key and value may show differences in case on FAT and NTFS f
 A similar approach could be used to determine the referenced data from $ref.  This would
 give access to
 
+The following script can be called from a windows explorer prompt as the alternative to the windows
+delete function (the windows delete action might potentially be reversed by a replication). 
+Obviously this will only function for file sand directories that are regularly synchronised using this
+module.
+
+     use strict;
+     use warnings;
+     my(@files) = @ARGV;
+     END {print "\nDONE -- PRESS ENTER\n";<STDIN>};
+     print << "End_Of_Header";
+     ================================================================================
+     
+     Executing $0\n
+     
+     This will mark files and/or directories for removal by the File::Repl file 
+     synchronisation utility.
+     
+     Files will be set to zero size when first processed by the File::Repl module, 
+     and finally removed after the tombstone period is expired.
+     
+     To reverse this process simply remove the added .remove file extension immediatly
+     
+     ================================================================================
+     
+     
+     End_Of_Header
+     
+     foreach my $file (@files){
+       print "$file\n";
+       if ($file =~ m/\.remove$/){
+     	  print "\t-is already marked for removal\n";
+       }elsif (-f $file){
+         unless (rename "$file","$file.remove"){
+           print "Unable to rename $file to $file.remove\n";
+         }else{
+     	  print "\t-marked for removal\n";
+       }
+       }
+       elsif (-d $file){
+         unless (rename "$file","$file.remove"){
+           print "Unable to rename $file to $file.remove\n";
+         }else{
+     	  print "\t-marked for removal\n";
+       }
+         }else{
+         print "File $file not found !!\n";
+       }
+     }
+
 =over 4
 
 =item alist (blist)
@@ -1274,19 +1413,23 @@ determined.
 
 =head1 AUTHOR
 
-Dave Roberts
+Dave Roberts <droberts@cpan.org>
 
+=head1 ACKNOWLEDGMENTS
+
+Thanks to Nigel Hodgson for his many contributions in developing this utility
+and helpin understanding fiel system specifics.
 
 
 =head1 SUPPORT
 
 You can send bug reports and suggestions for improvements on this module
-to me at DaveRoberts@iname.com. However, I can't promise to offer
-any other support for this script.
+to me at droberts@cpan.org. However, I can't promise to offer
+any other support for this package.
 
 =head1 COPYRIGHT
 
-This module is Copyright  2000, 2001 Dave Roberts. All rights reserved.
+This module is Copyright  2000 to 2010 Dave Roberts. All rights reserved.
 
 This script is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. This script is distributed in the
@@ -1298,7 +1441,38 @@ out of the use of the script.
 
 =head1 CHANGE HISTORY
 
-$Log: Repl.pm $
+$Log: repl.pm $
+Revision 1.29  2010/05/04 15:02:05  Dave.Roberts
+corrected documentation - layout near Update method was incorrect
+
+Revision 1.28  2010/04/27 14:55:00  Dave.Roberts
+minor code improvements in output messages for the Delete method
+
+Revision 1.27  2010/04/13 08:36:52  Dave.Roberts
+added functionality for testing negative ages. This allows files older than the age
+specified to be selected (excluding all files younger)
+
+Revision 1.26  2010/04/12 16:29:57  Dave.Roberts
+added Version method to return the File::Repl version
+corrected silly mistake in documentation - in definition of %con hash
+
+Revision 1.25  2010/04/12 16:04:54  Dave.Roberts
+added example script for tombstoning
+removed windows linefeed characters from file
+
+Revision 1.24  2010/04/07 02:00:11  Dave.Roberts
+modified code to remove the use of a hash as a reference - this was generating warnings
+as this use of a hash has beeen depreciated.
+
+Revision 1.21  2002/02/07 10:37:39  Dave.Roberts
+corrected mode identified for Update method (the check used previously
+was invalid), and also synopsis for use of Update method (args incorrectly
+ordered)
+
+Revision 1.20  2002/01/09 12:51:17  Dave.Roberts
+corrected errors in tombstoning of directories - subs $del and
+$deltree in particular
+
 Revision 1.19  2001/11/21 21:28:19  Dave.Roberts
 resolved error in determining file age, especially when the 'a' file is
 missing
@@ -1375,3 +1549,6 @@ minor code changes in constructing hash and improvement in documentation
 
 
 =cut
+
+
+
